pub async fn get_course_enrollments_info_for_user(
conn: &mut PgConnection,
user_id: Uuid,
) -> ModelResult<CourseEnrollmentsInfo>Expand description
Returns one entry per course the user is enrolled in, with aggregated data.
pub async fn get_course_enrollments_info_for_user(
conn: &mut PgConnection,
user_id: Uuid,
) -> ModelResult<CourseEnrollmentsInfo>Returns one entry per course the user is enrolled in, with aggregated data.